#
# spec file for package python-Flask-Babel
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2014 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-Flask-Babel
Version:        4.0.0
Release:        1.2
Summary:        i18n and l10n support for Flask
License:        BSD-3-Clause
URL:            https://github.com/python-babel/flask-babel
Source:         https://github.com/python-babel/flask-babel/archive/refs/tags/v%{version}.tar.gz#/Flask-Babel-%{version}.tar.gz
BuildRequires:  %{python_module Babel >= 2.12}
BuildRequires:  %{python_module Flask >= 2.0}
BuildRequires:  %{python_module Jinja2 >= 3.1}
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz >= 2022.7}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Babel >= 2.12
Requires:       python-Flask >= 2.0
Requires:       python-Jinja2 >= 3.1
Requires:       python-pytz >= 2022.7
BuildArch:      noarch
%python_subpackages

%description
This module implements i18n and l10n support for Flask. It is based on
the Python babel module as well as pytz.

%prep
%autosetup -p1 -n flask-babel-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/flask_babel
%{python_sitelib}/flask_babel-%{version}.dist-info

%changelog
* Wed Feb 21 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to 4.0.0:
  * Dropped support for end-of-life Python 3.7.
    Support PyPy 3.9
  * Replace deprecated locked_cached_property decorator with
    cached_property.
- Drop patch which is now included in 4.0.0 (which replaces
  deprecated locked_cached_property decorator):
  * support-flask-2.4.patch
* Thu Nov 30 2023 Antonio Larrosa <alarrosa@suse.com>
- Add %%{?sle15_python_module_pythons}
* Mon Aug 21 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-flask-2.4.patch:
  * Silence deprecation warnings.
* Thu Jun 15 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.1.0:
  * Don't return the default locale twice.
  * Fix tests breaking against babel 12.2, which changed localized times to
    use non-breaking-spaces.
  * Relax version requirements for dependencies.
  * Dropped support for end-of-life Python 3.5 and 3.6, added tests for 3.10
    and 3.11.
  * Jinja version 3 or greater is now required.
  * Removed Babel._date_formats, use the public Babel.date_formats instead.
  * list_translations() always returns the default locale, even if it does
    not exist.
  * Babel.locale_selector and Babel.timezone_selector no longer exist.
  * Most configuration options can be passed directly through init_app().
* Sat Sep  5 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * skip python2 builds
  * change to pytest
  * added pytz as requirement (from setup.py)
- update to version 2.0.0:
  * Starting with version 2, flask-babel drops official support for
    Python2.
  * Tests moved from unittest to pytest (#163)
  * Domain and caching support from Flask-BabelEx (#163)
  * Documentation moved from python-hosted to Github Pages.
  * CI moved from Travisci to Github Actions
  * Small documentation improvements.
  * Removed uncessary checks on get_translations() (#127, #126)
  * localeselector and timezoneselector can be changed after creation.
* Sun Feb 16 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 1.0.0:
  * pytz is an explicit dependency. (#14)
  * pytz.gae, used for Google App Engine, is no longer necessary and
    has been removed. (#153)
  * Fixed a deprecated werkzeug import (#158).
  * Fix issues switching locales in threaded contexts (#125).
* Sun Nov  4 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase.
* Tue Oct 30 2018 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * remove devel from noarch
  * be more specific in %%files section
  * add README.md
- update to version 0.12.2:
  * Switch to using README.md for project description on pypi.
  * Fix heading underline in index.rst
* Thu Aug 31 2017 toddrme2178@gmail.com
- Update to 0.11.2
  * No upstream changelog
- Implement single-spec version
* Thu Sep 15 2016 toddrme2178@gmail.com
- Update to 0.11.1
  * No upstream changelog
* Thu Oct 23 2014 axel.braun@gmx.de
- initial OBS build
